@@ -497,7 +497,7 @@ void
 gvc_stream_applet_icon_set_display_name (GvcStreamAppletIcon *icon,
                                          const gchar         *name)
 {
-        g_return_if_fail (GVC_STREAM_APPLET_ICON (icon));
+        g_return_if_fail (GVC_IS_STREAM_APPLET_ICON (icon));
 
         g_free (icon->priv->display_name);
 
@@ -511,7 +511,7 @@ void
 gvc_stream_applet_icon_set_control (GvcStreamAppletIcon    *icon,
                                     MateMixerStreamControl *control)
 {
-        g_return_if_fail (GVC_STREAM_APPLET_ICON (icon));
+        g_return_if_fail (GVC_IS_STREAM_APPLET_ICON (icon));
 
         if (icon->priv->control == control)
                 return;
@@ -763,6 +763,7 @@ gvc_stream_applet_icon_finalize (GObject *object)
         icon = GVC_STREAM_APPLET_ICON (object);
 
         g_strfreev (icon->priv->icon_names);
+        g_clear_pointer (&icon->priv->display_name, g_free);
 
         g_signal_handlers_disconnect_by_func (gtk_settings_get_default (),
                                               on_icon_theme_change,
